#
# spec file for package cppunit
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libcppunit-1_13-0
Name:           cppunit
Version:        1.13.2
Release:        6.3
Summary:        C++ Port of the JUnit Testing Framework
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            http://www.freedesktop.org/wiki/Software/cppunit
Source:         http://dev-www.libreoffice.org/src/%name-%version.tar.gz
Source1:        cppunit-devel.desktop
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
CppUnit is the C++ port of the famous JUnit framework for unit testing.
Test output is in XML for automatic testing and GUI based for
supervised tests.

%package -n %{libname}
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++

%description -n %{libname}
This package contains all necessary include files and libraries needed
to develop applications that require these.

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Suggests:       devel-doc = %{version}
Provides:       libcppunit-devel = %{version}
Obsoletes:      libcppunit-devel < %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%package devel-doc
Summary:        Documentation for the cppunit API
Group:          Documentation/HTML
Conflicts:      libcppunit-devel < 1.13.2
%if 0%{?suse_version} > 1200
BuildArch:      noarch
%endif

%description devel-doc
This package contains documentation for the cppunit API.

%prep
%setup -q

%build
export CXXFLAGS="%{optflags}"
%configure \
	--disable-static \
	--enable-doxygen
make %{?_smp_mflags} V=1

%install
make DESTDIR=%{buildroot} install
# remove la archive
rm %{buildroot}%{_libdir}/*.la
# this got also installed to _defaultdocdir
rm -rf %{buildroot}%{_datadir}/cppunit/html/
find %{buildroot}%{_includedir} -type f | xargs chmod a-x
# install susehelp file
mkdir -p %{buildroot}%{_datadir}/susehelp/meta/Development/Libraries/
install %{SOURCE1} %{buildroot}%{_datadir}/susehelp/meta/Development/Libraries/
%suse_update_desktop_file %{buildroot}%{_datadir}/susehelp/meta/Development/Libraries/cppunit-devel.desktop

%check
make check %{?_smp_mflags} V=1

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%doc AUTHORS COPYING
%{_libdir}/libcppunit*.so.*
%{_datadir}/cppunit

%files devel
%defattr(-,root,root)
%doc NEWS README THANKS ChangeLog
%{_bindir}/DllPlugInTester
%{_bindir}/cppunit-config
%{_libdir}/libcppunit*.so
%{_libdir}/pkgconfig/cppunit.pc
%{_includedir}/*
%{_mandir}/*/*
%{_datadir}/aclocal/cppunit.m4

%files devel-doc
%defattr(-,root,root)
%doc doc/html/*
%{_datadir}/susehelp

%changelog
* Thu Nov 14 2013 tchvatal@suse.com
- Avoid collisions with libcppunit.
* Wed Nov 13 2013 tchvatal@suse.com
- Fix the desktop file placement and help location within it.
* Tue Nov 12 2013 tchvatal@suse.com
- Fix baselibs.conf
- Run tests and split documentation in own devel-doc subpackage.
- Remove la file and do not build static lib.
* Mon Nov 11 2013 tbehrens@suse.com
- Version bump to 1.13.2
  * report dlopen errors now correctly
* Mon Dec 17 2012 tchvatal@suse.com
- Version bump to 1.13.1
  * remove unused patches that are incorporated in the build system
  * cleanup the spec file at least a bit
* Fri Nov 23 2012 joop.boonen@opensuse.org
- Fixed SLE build replaced make_install makro by
  make DESTDIR=\%%{buildroot} install
* Fri Apr 20 2012 joop.boonen@opensuse.org
- Build cppunit 1.12.1
- Passed  the spec file through spec-cleaner
* Thu Feb  9 2012 jengelh@medozas.de
- Simply regeneration of autotools scripts
* Sun Nov 13 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
- Add missing "make" call in %%build
* Sun Nov 13 2011 coolo@suse.com
- add libtool as explicit buildrequire to avoid implicit dependency from prjconf
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Sun Jul 15 2007 aj@suse.de
- Use libcppunit-devel to follow lib package name scheme
* Wed Jul  4 2007 adrian@suse.de
- update to version 0.12.0
  - minor bugfixes
  - now generated with doxygen 1.4.7 new 'tabs' style.
- rename package to follow lib package name scheme
* Sun Apr 22 2007 dmueller@suse.de
- don't install devel files as executable
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Aug 12 2005 dmueller@suse.de
- actually apply the quoting patch
* Tue Dec  7 2004 pth@suse.de
- Fix quoting in AC_DEFUN
* Tue Nov 16 2004 adrian@suse.de
- do not package debug dir
- translate suse help desktop file
* Thu Aug 12 2004 ro@suse.de
- added libpng to neededforbuild (for doxygen)
* Mon Jul 26 2004 adrian@suse.de
- remove unneeded /usr/bin/simple to solve conflicts
* Mon Jun 21 2004 adrian@suse.de
- update to version 1.10.2
- add susehelp desktop file
* Sat Mar 20 2004 adrian@suse.de
- remove executable permissions of header files (#36337)
* Tue Jul 29 2003 adrian@suse.de
- initial package of version 1.8.0
